@@ -341,11 +341,15 @@ connection_send_keep_alive (LmConnection *connection)
 static void
 connection_start_keep_alive (LmConnection *connection)
 {
-	/* try using TCP keepalives if possible */
-	if ((connection->keep_alive_rate > 0) &&
-		lm_socket_set_keepalive (connection->socket,
-			connection->keep_alive_rate)) {
-		return;
+        /* try using TCP keepalives if possible */
+        if ((connection->keep_alive_rate > 0) &&
+            lm_socket_set_keepalive (connection->socket,
+                                     connection->keep_alive_rate)) {
+#ifdef ONLY_TCP_KEEP_ALIVE
+                /* Many NAT firewalls seems to not handle this correctly and 
+                 * will disconnect the clients */
+                return;
+#endif /* ONLY_TCP_KEEP_ALIVE */
 	}
 
 	if (connection->keep_alive_source) {
@@ -578,14 +582,15 @@ connection_create_auth_msg (LmConnection *connection,
 	}
 
 	if (auth_type & AUTH_TYPE_DIGEST) {
-		gchar       *str;
-		const gchar *digest;
+		gchar *str;
+                gchar *digest;
 
 		lm_verbose ("Using digest\n");
 		str = g_strconcat (connection->stream_id, password, NULL);
 		digest = lm_sha_hash (str);
 		g_free (str);
 		lm_message_node_add_child (q_node, "digest", digest);
+                g_free (digest);
 	} 
 	else if (auth_type & AUTH_TYPE_PLAIN) {
 		lm_verbose ("Using plaintext auth\n");
