@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2003 Imendio HB
+ * Copyright (C) 2003 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License as
@@ -31,11 +31,20 @@ static struct TypeNames
         LmMessageType  type;
         const gchar   *name;
 } type_names[] = {
-	{ LM_MESSAGE_TYPE_MESSAGE,       "message"       },
-	{ LM_MESSAGE_TYPE_PRESENCE,      "presence"      },
-	{ LM_MESSAGE_TYPE_IQ,            "iq"            },
-	{ LM_MESSAGE_TYPE_STREAM,        "stream:stream" },
-	{ LM_MESSAGE_TYPE_STREAM_ERROR,  "stream:error"  }
+	{ LM_MESSAGE_TYPE_MESSAGE,         "message"         },
+	{ LM_MESSAGE_TYPE_PRESENCE,        "presence"        },
+	{ LM_MESSAGE_TYPE_IQ,              "iq"              },
+	{ LM_MESSAGE_TYPE_STREAM,          "stream:stream"   },
+	{ LM_MESSAGE_TYPE_STREAM_FEATURES, "stream:features" },
+	{ LM_MESSAGE_TYPE_STREAM_ERROR,    "stream:error"    },
+	{ LM_MESSAGE_TYPE_AUTH,            "auth"            },
+	{ LM_MESSAGE_TYPE_CHALLENGE,       "challenge"       },
+	{ LM_MESSAGE_TYPE_RESPONSE,        "response"        },
+	{ LM_MESSAGE_TYPE_SUCCESS,         "success"         },
+	{ LM_MESSAGE_TYPE_FAILURE,         "failure"         },
+	{ LM_MESSAGE_TYPE_PROCEED,         "proceed"         },
+	{ LM_MESSAGE_TYPE_STARTTLS,        "starttls"        },
+	{ LM_MESSAGE_TYPE_UNKNOWN,         NULL              }
 };
 
 static struct SubTypeNames 
@@ -75,10 +84,10 @@ message_type_from_string (const gchar *type_str)
         }
 
         for (i = LM_MESSAGE_TYPE_MESSAGE;
-	     i <= LM_MESSAGE_TYPE_STREAM_ERROR;
+	     i < LM_MESSAGE_TYPE_UNKNOWN;
 	     ++i) {
                 if (strcmp (type_str, type_names[i].name) == 0) {
-                        return i;
+                        return type_names[i].type;
                 }
         }
 
@@ -90,7 +99,7 @@ const gchar *
 _lm_message_type_to_string (LmMessageType type)
 {
         if (type < LM_MESSAGE_TYPE_MESSAGE ||
-            type > LM_MESSAGE_TYPE_STREAM_ERROR) {
+            type > LM_MESSAGE_TYPE_STARTTLS) {
                 type = LM_MESSAGE_TYPE_UNKNOWN;
         }
 
